==> orchestra-pvm-4.2.1-sources.jar: org/ow2/orchestra/pvm/internal/hibernate/HibernatePvmDbSession.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.hibernate;

import java.util.List;

import org.hibernate.Query;
import org.ow2.orchestra.pvm.Execution;
import org.ow2.orchestra.pvm.client.ClientExecution;
import org.ow2.orchestra.pvm.client.ClientProcessDefinition;
import org.ow2.orchestra.pvm.job.Job;
import org.ow2.orchestra.pvm.job.Message;
import org.ow2.orchestra.pvm.job.Timer;
import org.ow2.orchestra.pvm.session.PvmDbSession;

/**
 * @author Tom Baeyens
 */
public class HibernatePvmDbSession extends HibernateDbSession implements
    PvmDbSession {

  public HibernatePvmDbSession() {
  }

  public List<String> findProcessDefinitionNames() {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    return this.session.getNamedQuery("findProcessDefinitionNames").list();
  }

  public List<ClientProcessDefinition> findProcessDefinitionsByName(final String name) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findProcessDefinitionsByName");
    query.setString("name", name);
    return query.list();
  }

  public ClientProcessDefinition findProcessDefinitionByName(final String name,
      final int version) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session
        .getNamedQuery("findProcessDefinitionByNameAndVersion");
    query.setString("name", name);
    query.setInteger("version", version);
    final ClientProcessDefinition processDefinition = (ClientProcessDefinition) query
        .uniqueResult();
    return processDefinition;
  }

  public ClientProcessDefinition findLatestProcessDefinitionByName(final String name) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findProcessDefinitionsByName");
    query.setString("name", name);
    query.setMaxResults(1);
    final ClientProcessDefinition processDefinition = (ClientProcessDefinition) query
        .uniqueResult();
    return processDefinition;
  }

  public ClientProcessDefinition findProcessDefinitionById(
      final String processDefinitionId) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findProcessDefinitionsById");
    query.setString("id", processDefinitionId);
    query.setMaxResults(1);
    final ClientProcessDefinition processDefinition = (ClientProcessDefinition) query
        .uniqueResult();
    return processDefinition;
  }

  public ClientExecution findExecutionById(final String executionId) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findExecutionById");
    query.setString("id", executionId);
    query.setMaxResults(1);
    return (ClientExecution) query.uniqueResult();
  }

  public Execution findExecutionByKey(final String processDefinitionName,
      final String executionKey) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findExecutionByKey");
    query.setString("processDefinitionName", processDefinitionName);
    query.setString("executionKey", executionKey);
    query.setMaxResults(1);
    return (ClientExecution) query.uniqueResult();
  }

  public List<Timer> findTimers(final int firstResult, final int maxResults) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.job.hbm.xml
    final Query query = this.session.getNamedQuery("findTimers");
    query.setFirstResult(firstResult);
    query.setMaxResults(maxResults);
    return query.list();
  }

  public List<Message> findMessages(final int firstResult, final int maxResults) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.job.hbm.xml
    final Query query = this.session.getNamedQuery("findMessages");
    query.setFirstResult(firstResult);
    query.setMaxResults(maxResults);
    return query.list();
  }

  public List<Job> findJobsWithException(final int firstResult, final int maxResults) {
    // query definition can be found at the bottom resource
    // org/ow2/orchestra/pvm/hibernate.job.hbm.xml
    final Query query = this.session.getNamedQuery("findJobsWithException");
    query.setFirstResult(firstResult);
    query.setMaxResults(maxResults);
    return query.list();
  }
}

==> orchestra-pvm-4.4.1-sources.jar: org/ow2/orchestra/pvm/internal/hibernate/HibernatePvmDbSession.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.hibernate;

import java.util.List;

import org.hibernate.Query;
import org.ow2.orchestra.pvm.Execution;
import org.ow2.orchestra.pvm.client.ClientExecution;
import org.ow2.orchestra.pvm.client.ClientProcessDefinition;
import org.ow2.orchestra.pvm.job.Job;
import org.ow2.orchestra.pvm.job.Message;
import org.ow2.orchestra.pvm.job.Timer;
import org.ow2.orchestra.pvm.session.PvmDbSession;

/**
 * @author Tom Baeyens
 */
public class HibernatePvmDbSession extends HibernateDbSession implements
    PvmDbSession {

  public HibernatePvmDbSession() {
  }

  public List<String> findProcessDefinitionNames() {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    return this.session.getNamedQuery("findProcessDefinitionNames").list();
  }

  public List<ClientProcessDefinition> findProcessDefinitionsByName(final String name) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findProcessDefinitionsByName");
    query.setString("name", name);
    return query.list();
  }

  public ClientProcessDefinition findProcessDefinitionByName(final String name,
      final int version) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session
        .getNamedQuery("findProcessDefinitionByNameAndVersion");
    query.setString("name", name);
    query.setInteger("version", version);
    final ClientProcessDefinition processDefinition = (ClientProcessDefinition) query
        .uniqueResult();
    return processDefinition;
  }

  public ClientProcessDefinition findLatestProcessDefinitionByName(final String name) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findProcessDefinitionsByName");
    query.setString("name", name);
    query.setMaxResults(1);
    final ClientProcessDefinition processDefinition = (ClientProcessDefinition) query
        .uniqueResult();
    return processDefinition;
  }

  public ClientProcessDefinition findProcessDefinitionById(
      final String processDefinitionId) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findProcessDefinitionsById");
    query.setString("id", processDefinitionId);
    query.setMaxResults(1);
    final ClientProcessDefinition processDefinition = (ClientProcessDefinition) query
        .uniqueResult();
    return processDefinition;
  }

  public ClientExecution findExecutionById(final String executionId) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findExecutionById");
    query.setString("id", executionId);
    query.setMaxResults(1);
    return (ClientExecution) query.uniqueResult();
  }

  public Execution findExecutionByKey(final String processDefinitionName,
      final String executionKey) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.definition.hbm.xml
    final Query query = this.session.getNamedQuery("findExecutionByKey");
    query.setString("processDefinitionName", processDefinitionName);
    query.setString("executionKey", executionKey);
    query.setMaxResults(1);
    return (ClientExecution) query.uniqueResult();
  }

  public List<Timer> findTimers(final int firstResult, final int maxResults) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.job.hbm.xml
    final Query query = this.session.getNamedQuery("findTimers");
    query.setFirstResult(firstResult);
    query.setMaxResults(maxResults);
    return query.list();
  }

  public List<Message> findMessages(final int firstResult, final int maxResults) {
    // query definition can be found at the bottom of resource
    // org/ow2/orchestra/pvm/hibernate.job.hbm.xml
    final Query query = this.session.getNamedQuery("findMessages");
    query.setFirstResult(firstResult);
    query.setMaxResults(maxResults);
    return query.list();
  }

  public List<Job> findJobsWithException() {
    // query definition can be found at the bottom resource
    // org/ow2/orchestra/pvm/hibernate.job.hbm.xml
    final Query query = this.session.getNamedQuery("findJobsWithException");
    return query.list();
  }
}
